@@ -11,8 +11,6 @@ use base qw( Tangence::Object Circle::WindowItem Circle::Ruleable Circle::Config
 
 use constant NETTYPE => 'raw';
 
-use Tangence::Constants;
-
 use base qw( Circle::Rule::Store ); # for the attributes
 
 use Text::Balanced qw( extract_delimited );
@@ -22,22 +20,6 @@ use Circle::TaggedString;
 use Circle::Widget::Box;
 use Circle::Widget::Label;
 
-our %EVENTS = (
-   connected => {
-      args => [],
-   },
-   disconnected => {
-      args => [],
-   },
-);
-
-our %PROPS = (
-   connected => {
-      dim  => DIM_SCALAR,
-      type => 'bool',
-   },
-);
-
 sub new
 {
    my $class = shift;
@@ -260,6 +242,18 @@ sub commandable_parent
    return $self->{root};
 }
 
+sub enumerable_name
+{
+   my $self = shift;
+   return $self->get_prop_tag;
+}
+
+sub enumerable_parent
+{
+   my $self = shift;
+   return $self->{root};
+}
+
 ### Settings
 
 sub setting_host
